=======
History
=======

0.1.0 (2016-01-17)
------------------

* First release on PyPI.

0.2.0 (2016-01-17)
------------------

* Fixed Python 2 vs 3 compatibility.
* Updated documentation and setup TravisCI

0.2.1 (2016-01-19)
------------------

* Update interface with pddb
* Fix line endings

0.2.2 (2016-02-14)
------------------

* Added logout() function and corresponding documentation
* Updated example html file

0.2.3 (2016-02-15)
------------------

* Added logout() tests
* Added callback_success fallback for callback parameter in require_auth()

0.2.4 (2016-02-17)
------------------

* Dynamically import all public methods and classes from bottle
